==> pyloadl-0.0.1b1.tar.bz2: pyloadl-0.0.1b1/examples/llq_w.py <==
from pyloadl import *
from sys import exit

found = 0

# Initialize the query for jobs

qj = ll_query(JOBS)
if not qj:
   print "ll_query(): error\n" 
   exit(-1)

rc = ll_set_request(qj, QUERY_ALL, [""], ALL_DATA)
if rc != 0:
  print "  ll_set_request(): error %d\n" % rc
  exit(-1)

job, num, err = ll_get_objs(qj, LL_CM, "")
if err != 0:
  print "  ll_get_objs(): error %d\n" % err
  exit(-1)

while PyCObjValid(job):
    
   step = ll_get_data(job, LL_JobGetFirstStep)
   while PyCObjValid(step):
        
     id    = ll_get_data(step, LL_StepID)
     state = ll_get_data(step, LL_StepState)

     if (state == STATE_RUNNING):
            
        found = found + 1
        print "=============== Job Step id %s ===============" % id
        qw = ll_query(WLMSTAT)
        if (qw):

           rc = ll_set_request(qw, QUERY_STEPID, [id], ALL_DATA)
           machine =  ll_get_data(step, LL_StepGetFirstMachine)
           while PyCObjValid(machine):

             name = ll_get_data(machine, LL_MachineName)
             print "name: %s" % name

             # Get info from Startd on this machine
             wlm,num,err = ll_get_objs(qw, LL_STARTD, name)
             if (wlm):

               print "\tResource: CPU"
               cpu_snapshot = ll_get_data(wlm, LL_WlmStatCpuSnapshotUsage)
               print "\t\tsnapshot: %s" % cpu_snapshot
               cpu_total = ll_get_data(wlm, LL_WlmStatCpuTotalUsage)
               print "\t\ttotal: cpu_total"

               print "\tResource: Real Memory"
               memory_snapshot = ll_get_data(wlm, LL_WlmStatMemorySnapshotUsage)
               print "\t\tsnapshot: %s" % memory_snapshot

               memory_highwater = ll_get_data(wlm, LL_WlmStatMemoryHighWater)
               print "\t\thigh water: %s" % memory_highwater
               rc = ll_free_objs(qw)

               machine = ll_get_data(step, LL_StepGetNextMachine)
               rc = ll_deallocate(machine)
             else:
               print "  RESULT: No WLM object returned."

     step = ll_get_data(job, LL_JobGetNextStep)

   job = ll_next_obj(qj)

# free jobs obtained from Negotiator
rc = ll_free_objs(qj)

# free query element
rc = ll_deallocate(qj)

if (found == 0):
  print "There is currently no job status to report."

==> pyloadl-0.0.2.tar.bz2: pyloadl-0.0.2/examples/llq_w.py <==
from pyloadl import *
from sys import exit

found = 0

# Initialize the query for jobs

qj = ll_query(JOBS)
if not PyCObjValid(qj):
   print "ll_query(): returns NULL\n" 
   exit(-1)

rc = ll_set_request(qj, QUERY_ALL, [""], ALL_DATA)
if rc != 0:
  print "  ll_set_request(): error %d\n" % rc
  exit(-1)

job, num, err = ll_get_objs(qj, LL_CM, "")
if err != 0:
  print "  ll_get_objs(): error %d\n" % err
  exit(-1)

while PyCObjValid(job):
    
   step = ll_get_data(job, LL_JobGetFirstStep)
   while PyCObjValid(step):
        
     id    = ll_get_data(step, LL_StepID)
     state = ll_get_data(step, LL_StepState)

     if (state == STATE_RUNNING):
            
        found = found + 1
        print "=============== Job Step id %s ===============" % id
        qw = ll_query(WLMSTAT)
        if (qw):

           rc = ll_set_request(qw, QUERY_STEPID, [id], ALL_DATA)
           machine =  ll_get_data(step, LL_StepGetFirstMachine)
           while PyCObjValid(machine):

             name = ll_get_data(machine, LL_MachineName)
             print "name: %s" % name

             # Get info from Startd on this machine
             wlm,num,err = ll_get_objs(qw, LL_STARTD, name)
             if (wlm):

               print "\tResource: CPU"
               cpu_snapshot = ll_get_data(wlm, LL_WlmStatCpuSnapshotUsage)
               print "\t\tsnapshot: %s" % cpu_snapshot
               cpu_total = ll_get_data(wlm, LL_WlmStatCpuTotalUsage)
               print "\t\ttotal: cpu_total"

               print "\tResource: Real Memory"
               memory_snapshot = ll_get_data(wlm, LL_WlmStatMemorySnapshotUsage)
               print "\t\tsnapshot: %s" % memory_snapshot

               memory_highwater = ll_get_data(wlm, LL_WlmStatMemoryHighWater)
               print "\t\thigh water: %s" % memory_highwater
               rc = ll_free_objs(qw)

               machine = ll_get_data(step, LL_StepGetNextMachine)
               rc = ll_deallocate(machine)
             else:
               print "  RESULT: No WLM object returned."

     step = ll_get_data(job, LL_JobGetNextStep)

   job = ll_next_obj(qj)

# free jobs obtained from Negotiator
rc = ll_free_objs(qj)

# free query element
rc = ll_deallocate(qj)

if (found == 0):
  print "There is currently no job status to report."
